;;; highjump.scm

(day)
(set-track-name (_ "Speedjump"))
(fog)
(set-author "Gerard Pudenz")
(start-time 120)
(set-start-position 240 240)
(add-goal 240 234 #f "jump5")
